<?php
/**
 * Plugin Name: Multi Currency For WooCommerce
 * Description: Adds multi currency support to your WooCommerce store.
 * Version: 1.0.0
 * Author: Lion Plugins
 * Author URI: https://www.lionplugins.com
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

define( 'LION_MULTICURRENCY_VERSION', '1.0.0' );
define( 'LION_MULTICURRENCY_FILE', __FILE__ );
define( 'LION_MULTICURRENCY_PATH', untrailingslashit( plugin_dir_path( LION_MULTICURRENCY_FILE ) ) );
define( 'LION_MULTICURRENCY_URL', untrailingslashit( plugin_dir_url( LION_MULTICURRENCY_FILE ) ) );

if ( ! class_exists( 'Lion_MultiCurrency' ) ) :

	class Lion_MultiCurrency {

		/**
		 * Constructor.
		 */
		public function __construct() {
			add_action( 'plugins_loaded', array( $this, 'plugins_loaded' ) );
		}

		public function plugins_loaded() {
			$this->includes();

			add_action( 'wp_enqueue_scripts', array( $this, 'wp_enqueue_scripts' ) );
			add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), array( $this, 'plugin_settings_link' ) );
		}

		/**
		 * Includes.
		 */
		public function includes() {
			if ( ! is_admin() ) {

				// Nothing needs to be done for default currency
				if ( get_woocommerce_currency() != $this->get_current_currency() ) {
					include_once LION_MULTICURRENCY_PATH . '/inc/classes/class-product-price.php';
				}

				include_once LION_MULTICURRENCY_PATH . '/inc/classes/class-currency.php';
				include_once LION_MULTICURRENCY_PATH . '/inc/template-functions.php';
			} else {
				include_once LION_MULTICURRENCY_PATH . '/admin/class-admin.php';
			}

			include_once LION_MULTICURRENCY_PATH . '/inc/classes/class-exchange-service.php';
			include_once LION_MULTICURRENCY_PATH . '/inc/classes/class-widget.php';
		}

		/**
		 * Front-end styles.
		 */
		public function wp_enqueue_scripts() {
			wp_enqueue_style( 'multicurrency', LION_MULTICURRENCY_URL . '/assets/widget.css' );
		}

		/**
		 * Get current currency based on a parameter from URL or cookie.
		 *
		 * @return string
		 */
		public function get_current_currency() {
			$current_currency = get_woocommerce_currency();

			if ( isset( $_GET['lp_currency'] ) || isset( $_COOKIE['lp_currency'] ) ) {

				// Check URL first
				if ( isset( $_GET['lp_currency'] ) ) {
					$get_currency = sanitize_text_field( $_GET['lp_currency'] );
				} else {
					$get_currency = sanitize_text_field( $_COOKIE['lp_currency'] );
				}

				$default_currency = ( get_option( 'lionplugins_default_currency' ) ) ? get_option( 'lionplugins_default_currency' ) : array();
				$new_currencies = ( get_option( 'lionplugins_currencies' ) ) ? get_option( 'lionplugins_currencies' ) : array();

				$currencies = array( 'default' => $default_currency ) + $new_currencies;
				$currency_codes = array();

				if ( $currencies ) {
					foreach ( $currencies as $currency ) {
						if ( ! empty( $currency['code'] ) ) {
							$currency_codes[] = strtolower( $currency['code'] );
						}
					}
				}

				// Check if currency code exists in the currencies table
				if ( in_array( strtolower( $get_currency ), $currency_codes ) ) {
					$current_currency = $get_currency;
				}
			}

			return $current_currency;
		}

		/**
		 * Adds settings link in plugins page.
		 */
		public function plugin_settings_link( $links ) {
			$links[] = '<a href="' . esc_url(
				add_query_arg(
					array(
						'page' => 'wc-settings',
						'tab' => 'currencies',
					),
					admin_url( 'admin.php' )
				)
			) . '">' . __( 'Settings' ) . '</a>';
			return $links;
		}
	}

endif;

// Check if WooCommerce is activated
if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
	$Lion_MultiCurrency = new Lion_MultiCurrency();

	register_activation_hook( __FILE__, 'lionplugins_multicurrency_activate' );
	register_deactivation_hook( __FILE__, 'lionplugins_multicurrency_deactivate' );
} else {
	/**
	 * No WooCommerce plugin message.
	 */
	function lionplugins_no_woocommerce_message() {
		?>
		<div class="notice notice-error is-dismissible">
			<p><?php _e( 'Multi Currency For WooCommerce plugin is activated, but inactive. It requires WooCommerce plugin to work.', 'lionplugins' ); ?></p>
		</div>
		<?php
	}

	add_action( 'admin_notices', 'lionplugins_no_woocommerce_message' );
}

/**
 * The code that runs during plugin activation.
 */
function lionplugins_multicurrency_activate() {
	 // Add options
	if ( ! get_option( 'lionplugins_exchange_type' ) ) {
		add_option( 'lionplugins_exchange_type', 'table' );
	}

	if ( ! get_option( 'lionplugins_exchange_type' ) ) {
		add_option( 'lionplugins_enable_multicurrency_checkout', 'no' );
	}

	if ( ! get_option( 'lionplugins_exchange_service' ) ) {
		add_option( 'lionplugins_exchange_service', 'exchangeratesapi' );
	}

	$default_currency = array(
		'code' => get_woocommerce_currency(),
		'symbol' => '',
		'name' => get_woocommerce_currency(),
		'position' => get_option( 'woocommerce_currency_pos' ),
		'icon_url' => '',
	);
	if ( ! get_option( 'lionplugins_default_currency' ) ) {
		add_option( 'lionplugins_default_currency', $default_currency );
	}

	if ( ! class_exists( 'Lion_MultiCurrency_Exchange_Service' ) ) :
		include_once LION_MULTICURRENCY_PATH . '/inc/classes/class-exchange-service.php';
	endif;

	$lionplugins_exchange_service = new Lion_MultiCurrency_Exchange_Service();
	$lionplugins_exchange_service->get_currency_rates();

	if ( ! wp_next_scheduled( 'lionplugins_exchange_service' ) ) {
		wp_schedule_event( time(), 'daily', 'lionplugins_exchange_service' );
	}

	register_uninstall_hook( __FILE__, 'lionplugins_multicurrency_uninstall' );
}

/**
 * The code that runs during plugin deactivation.
 */
function lionplugins_multicurrency_deactivate() {
	wp_clear_scheduled_hook( 'lionplugins_exchange_service' );
}

/**
 * Uninstall hook.
 */
function lionplugins_multicurrency_uninstall() {
	delete_option( 'lionplugins_currencies' );
	delete_option( 'lionplugins_default_currency' );
	delete_option( 'lionplugins_exchange_rates' );
	delete_option( 'lionplugins_exchange_service_rates' );
	delete_option( 'lionplugins_enable_multicurrency_checkout' );
	delete_option( 'lionplugins_exchange_type' );
}
